@@ -26,13 +26,13 @@ options(warn=2)
 
 set.seed(100) # This may be removed, it ensures consistency of the daily tests
 
-## Simulate from Y=XB+E, the dimension of Y is N x K, X is N x p, B is p x K 
+## Simulate from Y=XB+E, the dimension of Y is N x K, X is N x p, B is p x K
 
 N <- 50 #number of samples
 p <- 25 #number of features
 K <- 10  #number of groups
 
-B<-matrix(sample(c(rep(1,p*K*0.1),rep(0, p*K-as.integer(p*K*0.1)))),nrow=p,ncol=K) 
+B<-matrix(sample(c(rep(1,p*K*0.1),rep(0, p*K-as.integer(p*K*0.1)))),nrow=p,ncol=K)
 X1<-matrix(rnorm(N*p,1,1),nrow=N,ncol=p)
 Y1 <-X1%*%B+matrix(rnorm(N*K,0,1),N,K)
 
@@ -50,3 +50,21 @@ y <- Y1[,1]
 lambda <- lsgl.lambda(X1, y, alpha = 1, d = 25, lambda.min = 0.5, intercept = FALSE)
 fit.cv <- lsgl.cv(X1, y, alpha = 1, lambda = lambda, intercept = FALSE, max.threads = 1)
 
+## Navigation tests
+Err(fit.cv)
+features_stat(fit.cv)
+parameters_stat(fit.cv)
+best_model(fit.cv)
+
+### Test for errors if X or Y contains NA
+Xna <- X1
+Xna[1,1] <- NA
+
+res <- try(fit.cv <- lsgl.cv(Xna, Y1, alpha = 1, lambda = lambda, intercept = FALSE, max.threads = 1), silent = TRUE)
+if(class(res) != "try-error") stop()
+
+Yna <- Y1
+Yna[1,1] <- NA
+
+res <- try(fit.cv <- lsgl.cv(X1, Yna, alpha = 1, lambda = lambda, intercept = FALSE, max.threads = 1), silent = TRUE)
+if(class(res) != "try-error") stop()
